"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, configuration_set: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a configuration set. Configuration sets enable you to publish email sending events. For information about using configuration sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        configuration_set(Dict): A data structure that contains the name of the configuration set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.init.create(ctx, configuration_set=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.init.create configuration_set=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="create_configuration_set",
        op_kwargs={"ConfigurationSet": configuration_set},
    )


async def delete(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a configuration set. Configuration sets enable you to publish email sending events. For information about using configuration sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.init.delete(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.init.delete configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_configuration_set",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def describe(
    hub,
    ctx,
    configuration_set_name: str,
    configuration_set_attribute_names: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of the specified configuration set. For information about using configuration sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set to describe.
        configuration_set_attribute_names(List, optional): A list of configuration set attributes to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.init.describe(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.init.describe configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="describe_configuration_set",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "ConfigurationSetAttributeNames": configuration_set_attribute_names,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_items: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of the configuration sets associated with your Amazon SES account in the current AWS Region. For information about using configuration sets, see Monitoring Your Amazon SES Sending Activity in the Amazon SES Developer Guide.  You can execute this operation no more than once per second. This operation will return up to 1,000 configuration sets each time it is run. If your Amazon SES account has more than 1,000 configuration sets, this operation will also return a NextToken element. You can then execute the ListConfigurationSets operation again, passing the NextToken parameter and the value of the NextToken element to retrieve additional results.

    Args:
        next_token(str, optional): A token returned from a previous call to ListConfigurationSets to indicate the position of the configuration set in the configuration set list. Defaults to None.
        max_items(int, optional): The number of configuration sets to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="list_configuration_sets",
        op_kwargs={"NextToken": next_token, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, aws_account_id: str, folder_id: str, member_id: str, member_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an asset, such as a dashboard, analysis, or dataset into a folder.

    Args:
        aws_account_id(str): The AWS Account ID.
        folder_id(str): The folder ID.
        member_id(str): The ID of the asset (the dashboard, analysis, or dataset).
        member_type(str): The type of the member, including DASHBOARD, ANALYSIS, and DATASET.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.membership.create(
                ctx, aws_account_id=value, folder_id=value, member_id=value, member_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.membership.create aws_account_id=value, folder_id=value, member_id=value, member_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_folder_membership",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "FolderId": folder_id,
            "MemberId": member_id,
            "MemberType": member_type,
        },
    )


async def delete(
    hub, ctx, aws_account_id: str, folder_id: str, member_id: str, member_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes an asset, such as a dashboard, analysis, or dataset, from a folder.

    Args:
        aws_account_id(str): The AWS Account ID.
        folder_id(str): The Folder ID.
        member_id(str): The ID of the asset (the dashboard, analysis, or dataset) that you want to delete.
        member_type(str): The type of the member, including DASHBOARD, ANALYSIS, and DATASET .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.membership.delete(
                ctx, aws_account_id=value, folder_id=value, member_id=value, member_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.membership.delete aws_account_id=value, folder_id=value, member_id=value, member_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_folder_membership",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "FolderId": folder_id,
            "MemberId": member_id,
            "MemberType": member_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about a gateway such as its name, network interfaces, configured time zone, and the state (whether the gateway is running or not). To specify which gateway to describe, use the Amazon Resource Name (ARN) of the gateway in your request.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.gateway.information.describe_all(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.gateway.information.describe_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_gateway_information",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def update_multiple(
    hub,
    ctx,
    gateway_arn: str,
    gateway_name: str = None,
    gateway_timezone: str = None,
    cloud_watch_log_group_arn: str = None,
    gateway_capacity: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a gateway's metadata, which includes the gateway's name and time zone. To specify which gateway to update, use the Amazon Resource Name (ARN) of the gateway in your request.  For gateways activated after September 2, 2015, the gateway's ARN contains the gateway ID rather than the gateway name. However, changing the name of the gateway has no effect on the gateway's ARN.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        gateway_name(str, optional): The name you configured for your gateway. Defaults to None.
        gateway_timezone(str, optional): A value that indicates the time zone of the gateway. Defaults to None.
        cloud_watch_log_group_arn(str, optional): The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that you want to use to monitor and log events in the gateway. For more information, see What is Amazon CloudWatch Logs? . Defaults to None.
        gateway_capacity(str, optional): Specifies the size of the gateway's metadata cache. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.gateway.information.update_multiple(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.gateway.information.update_multiple gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_gateway_information",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "GatewayName": gateway_name,
            "GatewayTimezone": gateway_timezone,
            "CloudWatchLogGroupARN": cloud_watch_log_group_arn,
            "GatewayCapacity": gateway_capacity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, update_phone_number_request_items: List) -> Dict:
    r"""
    **Autogenerated function**

    Updates phone number product types or calling names. You can update one attribute at a time for each UpdatePhoneNumberRequestItem. For example, you can update the product type or the calling name. For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type. Updates to outbound calling names can take up to 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.

    Args:
        update_phone_number_request_items(List): The request containing the phone number IDs and product types or calling names to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.update.phone_number.batch(
                ctx, update_phone_number_request_items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.update.phone_number.batch update_phone_number_request_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_update_phone_number",
        op_kwargs={"UpdatePhoneNumberRequestItems": update_phone_number_request_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    organization_id: str,
    name: str,
    effect: str,
    client_token: str = None,
    description: str = None,
    device_types: List = None,
    not_device_types: List = None,
    device_models: List = None,
    not_device_models: List = None,
    device_operating_systems: List = None,
    not_device_operating_systems: List = None,
    device_user_agents: List = None,
    not_device_user_agents: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new mobile device access rule for the specified Amazon WorkMail organization.

    Args:
        organization_id(str): The Amazon WorkMail organization under which the rule will be created.
        client_token(str, optional): The idempotency token for the client request. Defaults to None.
        name(str): The rule name.
        description(str, optional): The rule description. Defaults to None.
        effect(str): The effect of the rule when it matches. Allowed values are ALLOW or DENY.
        device_types(List, optional): Device types that the rule will match. Defaults to None.
        not_device_types(List, optional): Device types that the rule will not match. All other device types will match. Defaults to None.
        device_models(List, optional): Device models that the rule will match. Defaults to None.
        not_device_models(List, optional): Device models that the rule will not match. All other device models will match. Defaults to None.
        device_operating_systems(List, optional): Device operating systems that the rule will match. Defaults to None.
        not_device_operating_systems(List, optional): Device operating systems that the rule will not match. All other device operating systems will match. Defaults to None.
        device_user_agents(List, optional): Device user agents that the rule will match. Defaults to None.
        not_device_user_agents(List, optional): Device user agents that the rule will not match. All other device user agents will match. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mobile_device_access.rule.create(
                ctx, organization_id=value, name=value, effect=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mobile_device_access.rule.create organization_id=value, name=value, effect=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_mobile_device_access_rule",
        op_kwargs={
            "OrganizationId": organization_id,
            "ClientToken": client_token,
            "Name": name,
            "Description": description,
            "Effect": effect,
            "DeviceTypes": device_types,
            "NotDeviceTypes": not_device_types,
            "DeviceModels": device_models,
            "NotDeviceModels": not_device_models,
            "DeviceOperatingSystems": device_operating_systems,
            "NotDeviceOperatingSystems": not_device_operating_systems,
            "DeviceUserAgents": device_user_agents,
            "NotDeviceUserAgents": not_device_user_agents,
        },
    )


async def delete(
    hub, ctx, organization_id: str, mobile_device_access_rule_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a mobile device access rule for the specified Amazon WorkMail organization.

    Args:
        organization_id(str): The Amazon WorkMail organization under which the rule will be deleted.
        mobile_device_access_rule_id(str): The identifier of the rule to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mobile_device_access.rule.delete(
                ctx, organization_id=value, mobile_device_access_rule_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mobile_device_access.rule.delete organization_id=value, mobile_device_access_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_mobile_device_access_rule",
        op_kwargs={
            "OrganizationId": organization_id,
            "MobileDeviceAccessRuleId": mobile_device_access_rule_id,
        },
    )


async def list_all(hub, ctx, organization_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the mobile device access rules for the specified Amazon WorkMail organization.

    Args:
        organization_id(str): The Amazon WorkMail organization for which to list the rules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mobile_device_access.rule.list_all(
                ctx, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mobile_device_access.rule.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_mobile_device_access_rules",
        op_kwargs={"OrganizationId": organization_id},
    )


async def update(
    hub,
    ctx,
    organization_id: str,
    mobile_device_access_rule_id: str,
    name: str,
    effect: str,
    description: str = None,
    device_types: List = None,
    not_device_types: List = None,
    device_models: List = None,
    not_device_models: List = None,
    device_operating_systems: List = None,
    not_device_operating_systems: List = None,
    device_user_agents: List = None,
    not_device_user_agents: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a mobile device access rule for the specified Amazon WorkMail organization.

    Args:
        organization_id(str): The Amazon WorkMail organization under which the rule will be updated.
        mobile_device_access_rule_id(str): The identifier of the rule to be updated.
        name(str): The updated rule name.
        description(str, optional): The updated rule description. Defaults to None.
        effect(str): The effect of the rule when it matches. Allowed values are ALLOW or DENY.
        device_types(List, optional): Device types that the updated rule will match. Defaults to None.
        not_device_types(List, optional): Device types that the updated rule will not match. All other device types will match. Defaults to None.
        device_models(List, optional): Device models that the updated rule will match. Defaults to None.
        not_device_models(List, optional): Device models that the updated rule will not match. All other device models will match. Defaults to None.
        device_operating_systems(List, optional): Device operating systems that the updated rule will match. Defaults to None.
        not_device_operating_systems(List, optional): Device operating systems that the updated rule will not match. All other device operating systems will match. Defaults to None.
        device_user_agents(List, optional): User agents that the updated rule will match. Defaults to None.
        not_device_user_agents(List, optional): User agents that the updated rule will not match. All other user agents will match. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mobile_device_access.rule.update(
                ctx,
                organization_id=value,
                mobile_device_access_rule_id=value,
                name=value,
                effect=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mobile_device_access.rule.update organization_id=value, mobile_device_access_rule_id=value, name=value, effect=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="update_mobile_device_access_rule",
        op_kwargs={
            "OrganizationId": organization_id,
            "MobileDeviceAccessRuleId": mobile_device_access_rule_id,
            "Name": name,
            "Description": description,
            "Effect": effect,
            "DeviceTypes": device_types,
            "NotDeviceTypes": not_device_types,
            "DeviceModels": device_models,
            "NotDeviceModels": not_device_models,
            "DeviceOperatingSystems": device_operating_systems,
            "NotDeviceOperatingSystems": not_device_operating_systems,
            "DeviceUserAgents": device_user_agents,
            "NotDeviceUserAgents": not_device_user_agents,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, execution_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the state machine associated with a specific execution.  This operation is eventually consistent. The results are best effort and may not reflect very recent updates and changes.  This API action is not supported by EXPRESS state machines.

    Args:
        execution_arn(str): The Amazon Resource Name (ARN) of the execution you want state machine information for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.state_machine.for_execution.describe(
                ctx, execution_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.state_machine.for_execution.describe execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="describe_state_machine_for_execution",
        op_kwargs={"executionArn": execution_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    service_names: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes available services to which you can create a VPC endpoint. When the service provider and the consumer have different accounts in multiple Availability Zones, and the consumer views the VPC endpoint service information, the response only includes the common Availability Zones. For example, when the service provider account uses us-east-1a and us-east-1c and the consumer uses us-east-1a and us-east-1b, the response includes the VPC endpoint services in the common Availability Zone, us-east-1a.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_names(List, optional): One or more service names. Defaults to None.
        filters(List, optional): One or more filters.    service-name - The name of the service.    service-type - The type of service (Interface | Gateway).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. Constraint: If the value is greater than 1,000, we return only 1,000 items. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a prior call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoint_services",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceNames": service_names,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, operation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns the current status of an operation that is not completed.

    Args:
        operation_id(str): The identifier for the operation for which you want to get the status. Route 53 returned the identifier in the response to the original request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.operation.detail.get(ctx, operation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.operation.detail.get operation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="get_operation_detail",
        op_kwargs={"OperationId": operation_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    endpoint_id: str,
    destination_address: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the port mappings for a specific EC2 instance (destination) in a VPC subnet endpoint. The response is the mappings for one destination IP address. This is useful when your subnet endpoint has mappings that span multiple custom routing accelerators in your account, or for scenarios where you only want to list the port mappings for a specific destination instance.

    Args:
        endpoint_id(str): The ID for the virtual private cloud (VPC) subnet.
        destination_address(str): The endpoint IP address in a virtual private cloud (VPC) subnet for which you want to receive back port mappings.
        max_results(int, optional): The number of destination port mappings that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.port_mapping.by_destination.list(
                ctx, endpoint_id=value, destination_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.port_mapping.by_destination.list endpoint_id=value, destination_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_custom_routing_port_mappings_by_destination",
        op_kwargs={
            "EndpointId": endpoint_id,
            "DestinationAddress": destination_address,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def advertise(hub, ctx, cidr: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Advertises an IPv4 or IPv6 address range that is provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP). You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. We recommend that you stop advertising the BYOIP CIDR from other locations when you advertise it from Amazon Web Services. To minimize down time, you can configure your Amazon Web Services resources to use an address from a BYOIP CIDR before it is advertised, and then simultaneously stop advertising it from the current location and start advertising it through Amazon Web Services. It can take a few minutes before traffic to the specified addresses starts routing to Amazon Web Services because of BGP propagation delays. To stop advertising the BYOIP CIDR, use WithdrawByoipCidr.

    Args:
        cidr(str): The address range, in CIDR notation. This must be the exact range that you provisioned. You can't advertise only a portion of the provisioned range.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.byoip_cidr.advertise(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.byoip_cidr.advertise cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="advertise_byoip_cidr",
        op_kwargs={"Cidr": cidr, "DryRun": dry_run},
    )


async def deprovision(hub, ctx, cidr: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Releases the specified address range that you provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool. Before you can release an address range, you must stop advertising it using WithdrawByoipCidr and you must not have any IP addresses allocated from its address range.

    Args:
        cidr(str): The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.byoip_cidr.deprovision(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.byoip_cidr.deprovision cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="deprovision_byoip_cidr",
        op_kwargs={"Cidr": cidr, "DryRun": dry_run},
    )


async def describe_all(
    hub, ctx, max_results: int, dry_run: bool = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the IP address ranges that were specified in calls to ProvisionByoipCidr. To describe the address pools that were created when you provisioned the address ranges, use DescribePublicIpv4Pools or DescribeIpv6Pools.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.byoip_cidr.describe_all(ctx, max_results=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.byoip_cidr.describe_all max_results=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_byoip_cidrs",
        op_kwargs={
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def provision(
    hub,
    ctx,
    cidr: str,
    cidr_authorization_context: Dict = None,
    publicly_advertisable: bool = None,
    description: str = None,
    dry_run: bool = None,
    pool_tag_specifications: List = None,
    multi_region: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions an IPv4 or IPv6 address range for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool. After the address range is provisioned, it is ready to be advertised using AdvertiseByoipCidr. Amazon Web Services verifies that you own the address range and are authorized to advertise it. You must ensure that the address range is registered to you and that you created an RPKI ROA to authorize Amazon ASNs 16509 and 14618 to advertise the address range. For more information, see Bring your own IP addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. Provisioning an address range is an asynchronous operation, so the call returns immediately, but the address range is not ready to use until its status changes from pending-provision to provisioned. To monitor the status of an address range, use DescribeByoipCidrs. To allocate an Elastic IP address from your IPv4 address pool, use AllocateAddress with either the specific address from the address pool or the ID of the address pool.

    Args:
        cidr(str): The public IPv4 or IPv6 address range, in CIDR notation. The most specific IPv4 prefix that you can specify is /24. The most specific IPv6 prefix you can specify is /56. The address range cannot overlap with another address range that you've brought to this or another Region.
        cidr_authorization_context(Dict, optional): A signed document that proves that you are authorized to bring the specified IP address range to Amazon using BYOIP. Defaults to None.
        publicly_advertisable(bool, optional): (IPv6 only) Indicate whether the address range will be publicly advertised to the internet. Default: true. Defaults to None.
        description(str, optional): A description for the address range and the address pool. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        pool_tag_specifications(List, optional): The tags to apply to the address pool. Defaults to None.
        multi_region(bool, optional): Reserved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.byoip_cidr.provision(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.byoip_cidr.provision cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="provision_byoip_cidr",
        op_kwargs={
            "Cidr": cidr,
            "CidrAuthorizationContext": cidr_authorization_context,
            "PubliclyAdvertisable": publicly_advertisable,
            "Description": description,
            "DryRun": dry_run,
            "PoolTagSpecifications": pool_tag_specifications,
            "MultiRegion": multi_region,
        },
    )


async def withdraw(hub, ctx, cidr: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops advertising an address range that is provisioned as an address pool. You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. It can take a few minutes before traffic to the specified addresses stops routing to Amazon Web Services because of BGP propagation delays.

    Args:
        cidr(str): The address range, in CIDR notation.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.byoip_cidr.withdraw(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.byoip_cidr.withdraw cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="withdraw_byoip_cidr",
        op_kwargs={"Cidr": cidr, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    thing_group_name: str,
    recursive: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the things in the specified group.

    Args:
        thing_group_name(str): The thing group name.
        recursive(bool, optional): When true, list things in this thing group and in all child groups as well. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.in_.thing_group.list(ctx, thing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.in_.thing_group.list thing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_things_in_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "recursive": recursive,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "media_for_fragment_list"


async def get(
    hub, ctx, fragments: List, stream_name: str = None, stream_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets media for a list of fragments (specified by fragment number) from the archived data in an Amazon Kinesis video stream.  You must first call the GetDataEndpoint API to get an endpoint. Then send the GetMediaForFragmentList requests to this endpoint using the --endpoint-url parameter.   For limits, see Kinesis Video Streams Limits.  If an error is thrown after invoking a Kinesis Video Streams archived media API, in addition to the HTTP status code and the response body, it includes the following pieces of information:     x-amz-ErrorType HTTP header – contains a more specific error type in addition to what the HTTP status code provides.     x-amz-RequestId HTTP header – if you want to report an issue to AWS, the support team can better diagnose the problem if given the Request Id.   Both the HTTP status code and the ErrorType header can be utilized to make programmatic decisions about whether errors are retry-able and under what conditions, as well as provide information on what actions the client programmer might need to take in order to successfully try again. For more information, see the Errors section at the bottom of this topic, as well as Common Errors.

    Args:
        stream_name(str, optional): The name of the stream from which to retrieve fragment media. Specify either this parameter or the StreamARN parameter. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream from which to retrieve fragment media. Specify either this parameter or the StreamName parameter. Defaults to None.
        fragments(List): A list of the numbers of fragments for which to retrieve media. You retrieve these values with ListFragments.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_archived_media.media_for_fragment_list_.get(
                ctx, fragments=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_archived_media.media_for_fragment_list.get fragments=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-archived-media",
        operation="get_media_for_fragment_list",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "Fragments": fragments,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add one or more tags (keys and values) to a specified resource. A tag is a label that you optionally define and associate with a resource. Tags can help you categorize and manage resources in different ways, such as by purpose, owner, environment, or other criteria. A resource can have as many as 50 tags. Each tag consists of a required tag key and an associated tag value, both of which you define. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to add one or more tags to.
        tags(List): A list of the tags that you want to add to the resource. A tag consists of a required tag key (Key) and an associated tag value (Value). The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove one or more tags (keys and values) from a specified resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to remove one or more tags from.
        tag_keys(List): The tags (tag keys) that you want to remove from the resource. When you specify a tag key, the action removes both that key and its associated tag value. To remove more than one tag from the resource, append the TagKeys parameter and argument for each additional tag to remove, separated by an ampersand. For example: /v2/email/tags?ResourceArn=ResourceArn&TagKeys=Key1&TagKeys=Key2 .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, max_records: int = None, marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the replication instance types that can be created in the specified region.

    Args:
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.orderable_replication_instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.orderable_replication_instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_orderable_replication_instances",
        op_kwargs={"MaxRecords": max_records, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    task_id: str,
    finding_id: str,
    action_status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the status of audit mitigation action tasks that were executed.

    Args:
        task_id(str): Specify this filter to limit results to actions for a specific audit mitigation actions task.
        action_status(str, optional): Specify this filter to limit results to those with a specific status. Defaults to None.
        finding_id(str): Specify this filter to limit results to those that were applied to a specific audit finding.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.mitigation_action.execution.list_all(
                ctx, task_id=value, finding_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.mitigation_action.execution.list_all task_id=value, finding_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_audit_mitigation_actions_executions",
        op_kwargs={
            "taskId": task_id,
            "actionStatus": action_status,
            "findingId": finding_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, channel_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the active (live) stream on a specified channel.

    Args:
        channel_arn(str): Channel ARN for stream to be accessed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.init.get(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.init.get channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="get_stream",
        op_kwargs={"channelArn": channel_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about live streams in your account, in the AWS region where the API request is processed.

    Args:
        next_token(str, optional): The first stream to retrieve. This is used for pagination; see the nextToken response field. Defaults to None.
        max_results(int, optional): Maximum number of streams to return. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="list_streams",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def stop(hub, ctx, channel_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction with DeleteStreamKey to prevent further streaming to a channel.  Many streaming client-software libraries automatically reconnect a dropped RTMPS session, so to stop the stream permanently, you may want to first revoke the streamKey attached to the channel.

    Args:
        channel_arn(str): ARN of the channel for which the stream is to be stopped.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.stream.init.stop(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.stream.init.stop channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="stop_stream",
        op_kwargs={"channelArn": channel_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    distributions: List,
    client_token: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new distribution configuration. Distribution configurations define and configure the outputs of your pipeline.

    Args:
        name(str):  The name of the distribution configuration.
        description(str, optional):  The description of the distribution configuration. Defaults to None.
        distributions(List):  The distributions of the distribution configuration.
        tags(Dict, optional):  The tags of the distribution configuration. Defaults to None.
        client_token(str):  The idempotency token of the distribution configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.distribution_configuration.create(
                ctx, name=value, distributions=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.distribution_configuration.create name=value, distributions=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_distribution_configuration",
        op_kwargs={
            "name": name,
            "description": description,
            "distributions": distributions,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, distribution_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a distribution configuration.

    Args:
        distribution_configuration_arn(str): The Amazon Resource Name (ARN) of the distribution configuration to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.distribution_configuration.delete(
                ctx, distribution_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.distribution_configuration.delete distribution_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_distribution_configuration",
        op_kwargs={"distributionConfigurationArn": distribution_configuration_arn},
    )


async def get(hub, ctx, distribution_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets a distribution configuration.

    Args:
        distribution_configuration_arn(str): The Amazon Resource Name (ARN) of the distribution configuration that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.distribution_configuration.get(
                ctx, distribution_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.distribution_configuration.get distribution_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_distribution_configuration",
        op_kwargs={"distributionConfigurationArn": distribution_configuration_arn},
    )


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of distribution configurations.

    Args:
        filters(List, optional): The filters.    name - The name of this distribution configuration.  . Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.distribution_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.distribution_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_distribution_configurations",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    distribution_configuration_arn: str,
    distributions: List,
    client_token: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a new distribution configuration. Distribution configurations define and configure the outputs of your pipeline.

    Args:
        distribution_configuration_arn(str): The Amazon Resource Name (ARN) of the distribution configuration that you want to update.
        description(str, optional): The description of the distribution configuration. Defaults to None.
        distributions(List): The distributions of the distribution configuration.
        client_token(str): The idempotency token of the distribution configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.distribution_configuration.update(
                ctx, distribution_configuration_arn=value, distributions=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.distribution_configuration.update distribution_configuration_arn=value, distributions=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="update_distribution_configuration",
        op_kwargs={
            "distributionConfigurationArn": distribution_configuration_arn,
            "description": description,
            "distributions": distributions,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(
    hub, ctx, global_network_id: str, transit_gateway_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters a transit gateway from your global network. This action does not delete your transit gateway, or modify any of its attachments. This action removes any customer gateway associations.

    Args:
        global_network_id(str): The ID of the global network.
        transit_gateway_arn(str): The Amazon Resource Name (ARN) of the transit gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.transit_gateway.init.deregister(
                ctx, global_network_id=value, transit_gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.transit_gateway.init.deregister global_network_id=value, transit_gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="deregister_transit_gateway",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "TransitGatewayArn": transit_gateway_arn,
        },
    )


async def register(hub, ctx, global_network_id: str, transit_gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers a transit gateway in your global network. The transit gateway can be in any AWS Region, but it must be owned by the same AWS account that owns the global network. You cannot register a transit gateway in more than one global network.

    Args:
        global_network_id(str): The ID of the global network.
        transit_gateway_arn(str): The Amazon Resource Name (ARN) of the transit gateway. For more information, see Resources Defined by Amazon EC2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.transit_gateway.init.register(
                ctx, global_network_id=value, transit_gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.transit_gateway.init.register global_network_id=value, transit_gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="register_transit_gateway",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "TransitGatewayArn": transit_gateway_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    instance_id: str,
    instance_event_id: str,
    not_before: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the start time for a scheduled Amazon EC2 instance event.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance with the scheduled event.
        instance_event_id(str): The ID of the event whose date and time you are modifying.
        not_before(str): The new date and time when the event will take place.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.start_time.modify(
                ctx, instance_id=value, instance_event_id=value, not_before=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.start_time.modify instance_id=value, instance_event_id=value, not_before=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_event_start_time",
        op_kwargs={
            "DryRun": dry_run,
            "InstanceId": instance_id,
            "InstanceEventId": instance_event_id,
            "NotBefore": not_before,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    api_id: str,
    authorizer_type: str,
    identity_source: List,
    name: str,
    authorizer_credentials_arn: str = None,
    authorizer_payload_format_version: str = None,
    authorizer_result_ttl_in_seconds: int = None,
    authorizer_uri: str = None,
    enable_simple_responses: bool = None,
    identity_validation_expression: str = None,
    jwt_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Authorizer for an API.

    Args:
        api_id(str): The API identifier.
        authorizer_credentials_arn(str, optional): Specifies the required credentials as an IAM role for API Gateway to invoke the authorizer. To specify an IAM role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To use resource-based permissions on the Lambda function, don't specify this parameter. Supported only for REQUEST authorizers. Defaults to None.
        authorizer_payload_format_version(str, optional): Specifies the format of the payload sent to an HTTP API Lambda authorizer. Required for HTTP API Lambda authorizers. Supported values are 1.0 and 2.0. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. Defaults to None.
        authorizer_result_ttl_in_seconds(int, optional): The time to live (TTL) for cached authorizer results, in seconds. If it equals 0, authorization caching is disabled. If it is greater than 0, API Gateway caches authorizer responses. The maximum value is 3600, or 1 hour. Supported only for HTTP API Lambda authorizers. Defaults to None.
        authorizer_type(str): The authorizer type. Specify REQUEST for a Lambda function using incoming request parameters. Specify JWT to use JSON Web Tokens (supported only for HTTP APIs).
        authorizer_uri(str, optional): The authorizer's Uniform Resource Identifier (URI). For REQUEST authorizers, this must be a well-formed Lambda function URI, for example, arn:aws:apigateway:us-west-2:lambda:path/2015-03-31/functions/arn:aws:lambda:us-west-2:{account_id}:function:{lambda_function_name}/invocations. In general, the URI has this form: arn:aws:apigateway:{region}:lambda:path/{service_api}
               , where {region} is the same as the region hosting the Lambda function, path indicates that the remaining substring in the URI should be treated as the path to the resource, including the initial /. For Lambda functions, this is usually of the form /2015-03-31/functions/[FunctionARN]/invocations. Supported only for REQUEST authorizers. Defaults to None.
        enable_simple_responses(bool, optional): Specifies whether a Lambda authorizer returns a response in a simple format. By default, a Lambda authorizer must return an IAM policy. If enabled, the Lambda authorizer can return a boolean value instead of an IAM policy. Supported only for HTTP APIs. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. Defaults to None.
        identity_source(List): The identity source for which authorization is requested. For a REQUEST authorizer, this is optional. The value is a set of one or more mapping expressions of the specified request parameters. The identity source can be headers, query string parameters, stage variables, and context parameters. For example, if an Auth header and a Name query string parameter are defined as identity sources, this value is route.request.header.Auth, route.request.querystring.Name for WebSocket APIs. For HTTP APIs, use selection expressions prefixed with $, for example, $request.header.Auth, $request.querystring.Name. These parameters are used to perform runtime validation for Lambda-based authorizers by verifying all of the identity-related request parameters are present in the request, not null, and non-empty. Only when this is true does the authorizer invoke the authorizer Lambda function. Otherwise, it returns a 401 Unauthorized response without calling the Lambda function. For HTTP APIs, identity sources are also used as the cache key when caching is enabled. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. For JWT, a single entry that specifies where to extract the JSON Web Token (JWT) from inbound requests. Currently only header-based and query parameter-based selections are supported, for example $request.header.Authorization.
        identity_validation_expression(str, optional): This parameter is not used. Defaults to None.
        jwt_configuration(Dict, optional): Represents the configuration of a JWT authorizer. Required for the JWT authorizer type. Supported only for HTTP APIs. Defaults to None.
        name(str): The name of the authorizer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.authorizer.init.create(
                ctx, api_id=value, authorizer_type=value, identity_source=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.authorizer.init.create api_id=value, authorizer_type=value, identity_source=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_authorizer",
        op_kwargs={
            "ApiId": api_id,
            "AuthorizerCredentialsArn": authorizer_credentials_arn,
            "AuthorizerPayloadFormatVersion": authorizer_payload_format_version,
            "AuthorizerResultTtlInSeconds": authorizer_result_ttl_in_seconds,
            "AuthorizerType": authorizer_type,
            "AuthorizerUri": authorizer_uri,
            "EnableSimpleResponses": enable_simple_responses,
            "IdentitySource": identity_source,
            "IdentityValidationExpression": identity_validation_expression,
            "JwtConfiguration": jwt_configuration,
            "Name": name,
        },
    )


async def delete(hub, ctx, api_id: str, authorizer_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Authorizer.

    Args:
        api_id(str): The API identifier.
        authorizer_id(str): The authorizer identifier.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.authorizer.init.delete(
                ctx, api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.authorizer.init.delete api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_authorizer",
        op_kwargs={"ApiId": api_id, "AuthorizerId": authorizer_id},
    )


async def get(hub, ctx, api_id: str, authorizer_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Authorizer.

    Args:
        api_id(str): The API identifier.
        authorizer_id(str): The authorizer identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.authorizer.init.get(
                ctx, api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.authorizer.init.get api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_authorizer",
        op_kwargs={"ApiId": api_id, "AuthorizerId": authorizer_id},
    )


async def get_all(
    hub, ctx, api_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Authorizers for an API.

    Args:
        api_id(str): The API identifier.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.authorizer.init.get_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.authorizer.init.get_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_authorizers",
        op_kwargs={"ApiId": api_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    api_id: str,
    authorizer_id: str,
    authorizer_credentials_arn: str = None,
    authorizer_payload_format_version: str = None,
    authorizer_result_ttl_in_seconds: int = None,
    authorizer_type: str = None,
    authorizer_uri: str = None,
    enable_simple_responses: bool = None,
    identity_source: List = None,
    identity_validation_expression: str = None,
    jwt_configuration: Dict = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Authorizer.

    Args:
        api_id(str): The API identifier.
        authorizer_credentials_arn(str, optional): Specifies the required credentials as an IAM role for API Gateway to invoke the authorizer. To specify an IAM role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To use resource-based permissions on the Lambda function, don't specify this parameter. Defaults to None.
        authorizer_id(str): The authorizer identifier.
        authorizer_payload_format_version(str, optional): Specifies the format of the payload sent to an HTTP API Lambda authorizer. Required for HTTP API Lambda authorizers. Supported values are 1.0 and 2.0. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. Defaults to None.
        authorizer_result_ttl_in_seconds(int, optional): The time to live (TTL) for cached authorizer results, in seconds. If it equals 0, authorization caching is disabled. If it is greater than 0, API Gateway caches authorizer responses. The maximum value is 3600, or 1 hour. Supported only for HTTP API Lambda authorizers. Defaults to None.
        authorizer_type(str, optional): The authorizer type. Specify REQUEST for a Lambda function using incoming request parameters. Specify JWT to use JSON Web Tokens (supported only for HTTP APIs). Defaults to None.
        authorizer_uri(str, optional): The authorizer's Uniform Resource Identifier (URI). For REQUEST authorizers, this must be a well-formed Lambda function URI, for example, arn:aws:apigateway:us-west-2:lambda:path/2015-03-31/functions/arn:aws:lambda:us-west-2:{account_id}:function:{lambda_function_name}/invocations. In general, the URI has this form: arn:aws:apigateway:{region}:lambda:path/{service_api}
               , where {region} is the same as the region hosting the Lambda function, path indicates that the remaining substring in the URI should be treated as the path to the resource, including the initial /. For Lambda functions, this is usually of the form /2015-03-31/functions/[FunctionARN]/invocations. Supported only for REQUEST authorizers. Defaults to None.
        enable_simple_responses(bool, optional): Specifies whether a Lambda authorizer returns a response in a simple format. By default, a Lambda authorizer must return an IAM policy. If enabled, the Lambda authorizer can return a boolean value instead of an IAM policy. Supported only for HTTP APIs. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. Defaults to None.
        identity_source(List, optional): The identity source for which authorization is requested. For a REQUEST authorizer, this is optional. The value is a set of one or more mapping expressions of the specified request parameters. The identity source can be headers, query string parameters, stage variables, and context parameters. For example, if an Auth header and a Name query string parameter are defined as identity sources, this value is route.request.header.Auth, route.request.querystring.Name for WebSocket APIs. For HTTP APIs, use selection expressions prefixed with $, for example, $request.header.Auth, $request.querystring.Name. These parameters are used to perform runtime validation for Lambda-based authorizers by verifying all of the identity-related request parameters are present in the request, not null, and non-empty. Only when this is true does the authorizer invoke the authorizer Lambda function. Otherwise, it returns a 401 Unauthorized response without calling the Lambda function. For HTTP APIs, identity sources are also used as the cache key when caching is enabled. To learn more, see Working with AWS Lambda authorizers for HTTP APIs. For JWT, a single entry that specifies where to extract the JSON Web Token (JWT) from inbound requests. Currently only header-based and query parameter-based selections are supported, for example $request.header.Authorization. Defaults to None.
        identity_validation_expression(str, optional): This parameter is not used. Defaults to None.
        jwt_configuration(Dict, optional): Represents the configuration of a JWT authorizer. Required for the JWT authorizer type. Supported only for HTTP APIs. Defaults to None.
        name(str, optional): The name of the authorizer. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.authorizer.init.update(
                ctx, api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.authorizer.init.update api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_authorizer",
        op_kwargs={
            "ApiId": api_id,
            "AuthorizerCredentialsArn": authorizer_credentials_arn,
            "AuthorizerId": authorizer_id,
            "AuthorizerPayloadFormatVersion": authorizer_payload_format_version,
            "AuthorizerResultTtlInSeconds": authorizer_result_ttl_in_seconds,
            "AuthorizerType": authorizer_type,
            "AuthorizerUri": authorizer_uri,
            "EnableSimpleResponses": enable_simple_responses,
            "IdentitySource": identity_source,
            "IdentityValidationExpression": identity_validation_expression,
            "JwtConfiguration": jwt_configuration,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, domain: str, encryption_key: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a domain. CodeArtifact domains make it easier to manage multiple repositories across an organization. You can use a domain to apply permissions across many repositories owned by different AWS accounts. An asset is stored only once in a domain, even if it's in multiple repositories.  Although you can have multiple domains, we recommend a single production domain that contains all published artifacts so that your development teams can find and share packages. You can use a second pre-production domain to test changes to the production domain configuration.

    Args:
        domain(str):  The name of the domain to create. All domain names in an AWS Region that are in the same AWS account must be unique. The domain name is used as the prefix in DNS hostnames. Do not use sensitive information in a domain name because it is publicly discoverable. .
        encryption_key(str, optional):  The encryption key for the domain. This is used to encrypt content stored in a domain. An encryption key can be a key ID, a key Amazon Resource Name (ARN), a key alias, or a key alias ARN. To specify an encryptionKey, your IAM role must have kms:DescribeKey and kms:CreateGrant permissions on the encryption key that is used. For more information, see DescribeKey in the AWS Key Management Service API Reference and AWS KMS API Permissions Reference in the AWS Key Management Service Developer Guide.    CodeArtifact supports only symmetric CMKs. Do not associate an asymmetric CMK with your domain. For more information, see Using symmetric and asymmetric keys in the AWS Key Management Service Developer Guide.  . Defaults to None.
        tags(List, optional): One or more tag key-value pairs for the domain. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.init.create(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.init.create domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="create_domain",
        op_kwargs={"domain": domain, "encryptionKey": encryption_key, "tags": tags},
    )


async def delete(hub, ctx, domain: str, domain_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a domain. You cannot delete a domain that contains repositories. If you want to delete a domain with repositories, first delete its repositories.

    Args:
        domain(str):  The name of the domain to delete. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.init.delete(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.init.delete domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="delete_domain",
        op_kwargs={"domain": domain, "domainOwner": domain_owner},
    )


async def describe(hub, ctx, domain: str, domain_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a DomainDescription object that contains information about the requested domain.

    Args:
        domain(str):  A string that specifies the name of the requested domain. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.init.describe(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.init.describe domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="describe_domain",
        op_kwargs={"domain": domain, "domainOwner": domain_owner},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of DomainSummary objects for all domains owned by the AWS account that makes this call. Each returned DomainSummary object contains information about a domain.

    Args:
        max_results(int, optional):  The maximum number of results to return per page. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.domain.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.domain.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="list_domains",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    target_table_name: str,
    backup_arn: str,
    billing_mode_override: str = None,
    global_secondary_index_override: List = None,
    local_secondary_index_override: List = None,
    provisioned_throughput_override: Dict = None,
    sse_specification_override: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new table from an existing backup. Any number of users can execute up to 4 concurrent restores (any type of restore) in a given account.  You can call RestoreTableFromBackup at a maximum rate of 10 times per second. You must manually set up the following on the restored table:   Auto scaling policies   IAM policies   Amazon CloudWatch metrics and alarms   Tags   Stream settings   Time to Live (TTL) settings

    Args:
        target_table_name(str): The name of the new table to which the backup must be restored.
        backup_arn(str): The Amazon Resource Name (ARN) associated with the backup.
        billing_mode_override(str, optional): The billing mode of the restored table. Defaults to None.
        global_secondary_index_override(List, optional): List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore. Defaults to None.
        local_secondary_index_override(List, optional): List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore. Defaults to None.
        provisioned_throughput_override(Dict, optional): Provisioned throughput settings for the restored table. Defaults to None.
        sse_specification_override(Dict, optional): The new server-side encryption settings for the restored table. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.from_backup.restore(
                ctx, target_table_name=value, backup_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.from_backup.restore target_table_name=value, backup_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="restore_table_from_backup",
        op_kwargs={
            "TargetTableName": target_table_name,
            "BackupArn": backup_arn,
            "BillingModeOverride": billing_mode_override,
            "GlobalSecondaryIndexOverride": global_secondary_index_override,
            "LocalSecondaryIndexOverride": local_secondary_index_override,
            "ProvisionedThroughputOverride": provisioned_throughput_override,
            "SSESpecificationOverride": sse_specification_override,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(
    hub,
    ctx,
    portfolio_id: str,
    accept_language: str = None,
    portfolio_share_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts an offer to share the specified portfolio.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        portfolio_share_type(str, optional): The type of shared portfolios to accept. The default is to accept imported portfolios.    AWS_ORGANIZATIONS - Accept portfolios shared by the management account of your organization.    IMPORTED - Accept imported portfolios.    AWS_SERVICECATALOG - Not supported. (Throws ResourceNotFoundException.)   For example, aws servicecatalog accept-portfolio-share --portfolio-id "port-2qwzkwxt3y5fk" --portfolio-share-type AWS_ORGANIZATIONS . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.accept(
                ctx, portfolio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.accept portfolio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="accept_portfolio_share",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "PortfolioShareType": portfolio_share_type,
        },
    )


async def create(
    hub,
    ctx,
    portfolio_id: str,
    accept_language: str = None,
    account_id: str = None,
    organization_node: Dict = None,
    share_tag_options: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Shares the specified portfolio with the specified account or organization node. Shares to an organization node can only be created by the management account of an organization or by a delegated administrator. You can share portfolios to an organization, an organizational unit, or a specific account. Note that if a delegated admin is de-registered, they can no longer create portfolio shares.  AWSOrganizationsAccess must be enabled in order to create a portfolio share to an organization node. You can't share a shared resource, including portfolios that contain a shared product. If the portfolio share with the specified account or organization node already exists, this action will have no effect and will not return an error. To update an existing share, you must use the  UpdatePortfolioShare API instead.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        account_id(str, optional): The AWS account ID. For example, 123456789012. Defaults to None.
        organization_node(Dict, optional): The organization node to whom you are going to share. If OrganizationNode is passed in, PortfolioShare will be created for the node an ListOrganizationPortfolioAccessd its children (when applies), and a PortfolioShareToken will be returned in the output in order for the administrator to monitor the status of the PortfolioShare creation process. Defaults to None.
        share_tag_options(bool, optional): Enables or disables TagOptions  sharing when creating the portfolio share. If this flag is not provided, TagOptions sharing is disabled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.create(
                ctx, portfolio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.create portfolio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_portfolio_share",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "AccountId": account_id,
            "OrganizationNode": organization_node,
            "ShareTagOptions": share_tag_options,
        },
    )


async def delete(
    hub,
    ctx,
    portfolio_id: str,
    accept_language: str = None,
    account_id: str = None,
    organization_node: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stops sharing the specified portfolio with the specified account or organization node. Shares to an organization node can only be deleted by the management account of an organization or by a delegated administrator. Note that if a delegated admin is de-registered, portfolio shares created from that account are removed.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        account_id(str, optional): The AWS account ID. Defaults to None.
        organization_node(Dict, optional): The organization node to whom you are going to stop sharing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.delete(
                ctx, portfolio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.delete portfolio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_portfolio_share",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "AccountId": account_id,
            "OrganizationNode": organization_node,
        },
    )


async def describe_all(
    hub,
    ctx,
    portfolio_id: str,
    type_: str,
    page_token: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a summary of each of the portfolio shares that were created for the specified portfolio. You can use this API to determine which accounts or organizational nodes this portfolio have been shared, whether the recipient entity has imported the share, and whether TagOptions are included with the share. The PortfolioId and Type parameters are both required.

    Args:
        portfolio_id(str): The unique identifier of the portfolio for which shares will be retrieved.
        type_(str): The type of portfolio share to summarize. This field acts as a filter on the type of portfolio share, which can be one of the following: 1. ACCOUNT - Represents an external account to account share. 2. ORGANIZATION - Represents a share to an organization. This share is available to every account in the organization. 3. ORGANIZATIONAL_UNIT - Represents a share to an organizational unit. 4. ORGANIZATION_MEMBER_ACCOUNT - Represents a share to an account in the organization.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.describe_all(
                ctx, portfolio_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.describe_all portfolio_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_portfolio_shares",
        op_kwargs={
            "PortfolioId": portfolio_id,
            "Type": type_,
            "PageToken": page_token,
            "PageSize": page_size,
        },
    )


async def reject(
    hub,
    ctx,
    portfolio_id: str,
    accept_language: str = None,
    portfolio_share_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects an offer to share the specified portfolio.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        portfolio_share_type(str, optional): The type of shared portfolios to reject. The default is to reject imported portfolios.    AWS_ORGANIZATIONS - Reject portfolios shared by the management account of your organization.    IMPORTED - Reject imported portfolios.    AWS_SERVICECATALOG - Not supported. (Throws ResourceNotFoundException.)   For example, aws servicecatalog reject-portfolio-share --portfolio-id "port-2qwzkwxt3y5fk" --portfolio-share-type AWS_ORGANIZATIONS . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.reject(
                ctx, portfolio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.reject portfolio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="reject_portfolio_share",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "PortfolioShareType": portfolio_share_type,
        },
    )


async def update(
    hub,
    ctx,
    portfolio_id: str,
    accept_language: str = None,
    account_id: str = None,
    organization_node: Dict = None,
    share_tag_options: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified portfolio share. You can use this API to enable or disable TagOptions sharing for an existing portfolio share.  The portfolio share cannot be updated if the  CreatePortfolioShare operation is IN_PROGRESS, as the share is not available to recipient entities. In this case, you must wait for the portfolio share to be COMPLETED. You must provide the accountId or organization node in the input, but not both. If the portfolio is shared to both an external account and an organization node, and both shares need to be updated, you must invoke UpdatePortfolioShare separately for each share type.  This API cannot be used for removing the portfolio share. You must use DeletePortfolioShare API for that action.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The unique identifier of the portfolio for which the share will be updated.
        account_id(str, optional): The AWS Account Id of the recipient account. This field is required when updating an external account to account type share. Defaults to None.
        organization_node(Dict, optional): Information about the organization node. Defaults to None.
        share_tag_options(bool, optional): A flag to enable or disable TagOptions sharing for the portfolio share. If this field is not provided, the current state of TagOptions sharing on the portfolio share will not be modified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.portfolio.share.init.update(
                ctx, portfolio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.portfolio.share.init.update portfolio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_portfolio_share",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "AccountId": account_id,
            "OrganizationNode": organization_node,
            "ShareTagOptions": share_tag_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    directory_arn: str,
    typed_link_specifier: Dict,
    attribute_names: List,
    consistency_level: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves attributes that are associated with a typed link.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the typed link resides. For more information, see arns or Typed Links.
        typed_link_specifier(Dict): Allows a typed link specifier to be accepted as input.
        attribute_names(List): A list of attribute names whose values will be retrieved.
        consistency_level(str, optional): The consistency level at which to retrieve the attributes on a typed link. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.link_attribute.get_all(
                ctx, directory_arn=value, typed_link_specifier=value, attribute_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.link_attribute.get_all directory_arn=value, typed_link_specifier=value, attribute_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_link_attributes",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "TypedLinkSpecifier": typed_link_specifier,
            "AttributeNames": attribute_names,
            "ConsistencyLevel": consistency_level,
        },
    )


async def update_multiple(
    hub, ctx, directory_arn: str, typed_link_specifier: Dict, attribute_updates: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a given typed link’s attributes. Attributes to be updated must not contribute to the typed link’s identity, as defined by its IdentityAttributeOrder.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the updated typed link resides. For more information, see arns or Typed Links.
        typed_link_specifier(Dict): Allows a typed link specifier to be accepted as input.
        attribute_updates(List): The attributes update structure.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.link_attribute.update_multiple(
                ctx, directory_arn=value, typed_link_specifier=value, attribute_updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.link_attribute.update_multiple directory_arn=value, typed_link_specifier=value, attribute_updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="update_link_attributes",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "TypedLinkSpecifier": typed_link_specifier,
            "AttributeUpdates": attribute_updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, collection_name: str, device_position_updates: List) -> Dict:
    r"""
    **Autogenerated function**

    Evaluates device positions against the geofence geometries from a given geofence collection. This operation always returns an empty response because geofences are asynchronously evaluated. The evaluation determines if the device has entered or exited a geofenced area, and then publishes one of the following events to Amazon EventBridge:    ENTER if Amazon Location determines that the tracked device has entered a geofenced area.    EXIT if Amazon Location determines that the tracked device has exited a geofenced area.    The last geofence that a device was observed within is tracked for 30 days after the most recent device position update.

    Args:
        collection_name(str): The geofence collection used in evaluating the position of devices against its geofences.
        device_position_updates(List): Contains device details for each device to be evaluated against the given geofence collection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.evaluate_geofence.batch(
                ctx, collection_name=value, device_position_updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.evaluate_geofence.batch collection_name=value, device_position_updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="batch_evaluate_geofences",
        op_kwargs={
            "CollectionName": collection_name,
            "DevicePositionUpdates": device_position_updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS Elemental MediaConvert.

    Args:
        arn(str): The ARN of the ACM certificate that you want to associate with your MediaConvert resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.certificate.associate(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.certificate.associate arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="associate_certificate",
        op_kwargs={"Arn": arn},
    )


async def disassociate(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an association between the Amazon Resource Name (ARN) of an AWS Certificate Manager (ACM) certificate and an AWS Elemental MediaConvert resource.

    Args:
        arn(str): The ARN of the ACM certificate that you want to disassociate from your MediaConvert resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.certificate.disassociate(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.certificate.disassociate arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="disassociate_certificate",
        op_kwargs={"Arn": arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    content_type: str,
    content: str,
    connection_token: str,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a message. Note that ConnectionToken is used for invoking this API instead of ParticipantToken.  The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.

    Args:
        content_type(str): The type of the content. Supported types are text/plain.
        content(str): The content of the message.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        connection_token(str): The authentication token associated with the connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.message.send(
                ctx, content_type=value, content=value, connection_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.message.send content_type=value, content=value, connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="send_message",
        op_kwargs={
            "ContentType": content_type,
            "Content": content,
            "ClientToken": client_token,
            "ConnectionToken": connection_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub,
    ctx,
    rule: Dict,
    expression: str,
    language: str,
    outcomes: List,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a rule version resulting in a new rule version. Updates a rule version resulting in a new rule version (version 1, 2, 3 ...).

    Args:
        rule(Dict): The rule to update.
        description(str, optional): The description. Defaults to None.
        expression(str): The rule expression.
        language(str): The language.
        outcomes(List): The outcomes.
        tags(List, optional): The tags to assign to the rule version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.rule.version.update(
                ctx, rule=value, expression=value, language=value, outcomes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.rule.version.update rule=value, expression=value, language=value, outcomes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_rule_version",
        op_kwargs={
            "rule": rule,
            "description": description,
            "expression": expression,
            "language": language,
            "outcomes": outcomes,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def compose(
    hub,
    ctx,
    application_name: str = None,
    group_name: str = None,
    version_labels: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create or update a group of environments that each run a separate component of a single application. Takes a list of version labels that specify application source bundles for each of the environments to create or update. The name of each environment and other required information must be included in the source bundles in an environment manifest named env.yaml. See Compose Environments for details.

    Args:
        application_name(str, optional): The name of the application to which the specified source bundles belong. Defaults to None.
        group_name(str, optional): The name of the group to which the target environments belong. Specify a group name only if the environment name defined in each target environment's manifest ends with a + (plus) character. See Environment Manifest (env.yaml) for details. Defaults to None.
        version_labels(List, optional): A list of version labels, specifying one or more application source bundles that belong to the target application. Each source bundle must include an environment manifest that specifies the name of the environment and the name of the solution stack to use, and optionally can specify environment links to create. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.compose(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.compose
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="compose_environments",
        op_kwargs={
            "ApplicationName": application_name,
            "GroupName": group_name,
            "VersionLabels": version_labels,
        },
    )


async def create(
    hub,
    ctx,
    application_name: str,
    environment_name: str = None,
    group_name: str = None,
    description: str = None,
    cname_prefix: str = None,
    tier: Dict = None,
    tags: List = None,
    version_label: str = None,
    template_name: str = None,
    solution_stack_name: str = None,
    platform_arn: str = None,
    option_settings: List = None,
    options_to_remove: List = None,
    operations_role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Launches an AWS Elastic Beanstalk environment for the specified application using the specified configuration.

    Args:
        application_name(str): The name of the application that is associated with this environment.
        environment_name(str, optional): A unique name for the environment. Constraint: Must be from 4 to 40 characters in length. The name can contain only letters, numbers, and hyphens. It can't start or end with a hyphen. This name must be unique within a region in your account. If the specified name already exists in the region, Elastic Beanstalk returns an InvalidParameterValue error.  If you don't specify the CNAMEPrefix parameter, the environment name becomes part of the CNAME, and therefore part of the visible URL for your application. Defaults to None.
        group_name(str, optional): The name of the group to which the target environment belongs. Specify a group name only if the environment's name is specified in an environment manifest and not with the environment name parameter. See Environment Manifest (env.yaml) for details. Defaults to None.
        description(str, optional): Your description for this environment. Defaults to None.
        cname_prefix(str, optional): If specified, the environment attempts to use this value as the prefix for the CNAME in your Elastic Beanstalk environment URL. If not specified, the CNAME is generated automatically by appending a random alphanumeric string to the environment name. Defaults to None.
        tier(Dict, optional): Specifies the tier to use in creating this environment. The environment tier that you choose determines whether Elastic Beanstalk provisions resources to support a web application that handles HTTP(S) requests or a web application that handles background-processing tasks. Defaults to None.
        tags(List, optional): Specifies the tags applied to resources in the environment. Defaults to None.
        version_label(str, optional): The name of the application version to deploy. Default: If not specified, Elastic Beanstalk attempts to deploy the sample application. Defaults to None.
        template_name(str, optional): The name of the Elastic Beanstalk configuration template to use with the environment.  If you specify TemplateName, then don't specify SolutionStackName. . Defaults to None.
        solution_stack_name(str, optional): The name of an Elastic Beanstalk solution stack (platform version) to use with the environment. If specified, Elastic Beanstalk sets the configuration values to the default values associated with the specified solution stack. For a list of current solution stacks, see Elastic Beanstalk Supported Platforms in the AWS Elastic Beanstalk Platforms guide.  If you specify SolutionStackName, don't specify PlatformArn or TemplateName. . Defaults to None.
        platform_arn(str, optional): The Amazon Resource Name (ARN) of the custom platform to use with the environment. For more information, see Custom Platforms in the AWS Elastic Beanstalk Developer Guide.  If you specify PlatformArn, don't specify SolutionStackName. . Defaults to None.
        option_settings(List, optional): If specified, AWS Elastic Beanstalk sets the specified configuration options to the requested value in the configuration set for the new environment. These override the values obtained from the solution stack or the configuration template. Defaults to None.
        options_to_remove(List, optional): A list of custom user-defined configuration options to remove from the configuration set for this new environment. Defaults to None.
        operations_role(str, optional): The Amazon Resource Name (ARN) of an existing IAM role to be used as the environment's operations role. If specified, Elastic Beanstalk uses the operations role for permissions to downstream services during this call and during subsequent calls acting on this environment. To specify an operations role, you must have the iam:PassRole permission for the role. For more information, see Operations roles in the AWS Elastic Beanstalk Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.create(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.create application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_environment",
        op_kwargs={
            "ApplicationName": application_name,
            "EnvironmentName": environment_name,
            "GroupName": group_name,
            "Description": description,
            "CNAMEPrefix": cname_prefix,
            "Tier": tier,
            "Tags": tags,
            "VersionLabel": version_label,
            "TemplateName": template_name,
            "SolutionStackName": solution_stack_name,
            "PlatformArn": platform_arn,
            "OptionSettings": option_settings,
            "OptionsToRemove": options_to_remove,
            "OperationsRole": operations_role,
        },
    )


async def describe_all(
    hub,
    ctx,
    application_name: str = None,
    version_label: str = None,
    environment_ids: List = None,
    environment_names: List = None,
    include_deleted: bool = None,
    included_deleted_back_to: str = None,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptions for existing environments.

    Args:
        application_name(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application. Defaults to None.
        version_label(str, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version. Defaults to None.
        environment_ids(List, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs. Defaults to None.
        environment_names(List, optional): If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names. Defaults to None.
        include_deleted(bool, optional): Indicates whether to include deleted environments:  true: Environments that have been deleted after IncludedDeletedBackTo are displayed.  false: Do not include deleted environments. Defaults to None.
        included_deleted_back_to(str, optional):  If specified when IncludeDeleted is set to true, then environments deleted after this date are displayed. . Defaults to None.
        max_records(int, optional): For a paginated request. Specify a maximum number of environments to include in each response. If no MaxRecords is specified, all available environments are retrieved in a single response. Defaults to None.
        next_token(str, optional): For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request. If no NextToken is specified, the first page is retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_environments",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabel": version_label,
            "EnvironmentIds": environment_ids,
            "EnvironmentNames": environment_names,
            "IncludeDeleted": include_deleted,
            "IncludedDeletedBackTo": included_deleted_back_to,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )


async def rebuild(
    hub, ctx, environment_id: str = None, environment_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes and recreates all of the AWS resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.

    Args:
        environment_id(str, optional): The ID of the environment to rebuild.  Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to rebuild.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.rebuild(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.rebuild
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="rebuild_environment",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
        },
    )


async def terminate(
    hub,
    ctx,
    environment_id: str = None,
    environment_name: str = None,
    terminate_resources: bool = None,
    force_terminate: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Terminates the specified environment.

    Args:
        environment_id(str, optional): The ID of the environment to terminate.  Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to terminate.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        terminate_resources(bool, optional): Indicates whether the associated AWS resources should shut down when the environment is terminated:    true: The specified environment as well as the associated AWS resources, such as Auto Scaling group and LoadBalancer, are terminated.    false: AWS Elastic Beanstalk resource management is removed from the environment, but the AWS resources continue to operate.    For more information, see the  AWS Elastic Beanstalk User Guide.    Default: true   Valid Values: true | false . Defaults to None.
        force_terminate(bool, optional): Terminates the target environment even if another environment in the same group is dependent on it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.terminate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.terminate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="terminate_environment",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "TerminateResources": terminate_resources,
            "ForceTerminate": force_terminate,
        },
    )


async def update(
    hub,
    ctx,
    application_name: str = None,
    environment_id: str = None,
    environment_name: str = None,
    group_name: str = None,
    description: str = None,
    tier: Dict = None,
    version_label: str = None,
    template_name: str = None,
    solution_stack_name: str = None,
    platform_arn: str = None,
    option_settings: List = None,
    options_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment.  Attempting to update both the release and configuration is not allowed and AWS Elastic Beanstalk returns an InvalidParameterCombination error.   When updating the configuration settings to a new template or individual settings, a draft configuration is created and DescribeConfigurationSettings for this environment returns two setting descriptions with different DeploymentStatus values.

    Args:
        application_name(str, optional): The name of the application with which the environment is associated. Defaults to None.
        environment_id(str, optional): The ID of the environment to update. If no environment with this ID exists, AWS Elastic Beanstalk returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to update. If no environment with this name exists, AWS Elastic Beanstalk returns an InvalidParameterValue error.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        group_name(str, optional): The name of the group to which the target environment belongs. Specify a group name only if the environment's name is specified in an environment manifest and not with the environment name or environment ID parameters. See Environment Manifest (env.yaml) for details. Defaults to None.
        description(str, optional): If this parameter is specified, AWS Elastic Beanstalk updates the description of this environment. Defaults to None.
        tier(Dict, optional): This specifies the tier to use to update the environment. Condition: At this time, if you change the tier version, name, or type, AWS Elastic Beanstalk returns InvalidParameterValue error. . Defaults to None.
        version_label(str, optional): If this parameter is specified, AWS Elastic Beanstalk deploys the named application version to the environment. If no such application version is found, returns an InvalidParameterValue error. . Defaults to None.
        template_name(str, optional): If this parameter is specified, AWS Elastic Beanstalk deploys this configuration template to the environment. If no such configuration template is found, AWS Elastic Beanstalk returns an InvalidParameterValue error. . Defaults to None.
        solution_stack_name(str, optional): This specifies the platform version that the environment will run after the environment is updated. Defaults to None.
        platform_arn(str, optional): The ARN of the platform, if used. Defaults to None.
        option_settings(List, optional): If specified, AWS Elastic Beanstalk updates the configuration set associated with the running environment and sets the specified configuration options to the requested value. Defaults to None.
        options_to_remove(List, optional): A list of custom user-defined configuration options to remove from the configuration set for this environment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_environment",
        op_kwargs={
            "ApplicationName": application_name,
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
            "GroupName": group_name,
            "Description": description,
            "Tier": tier,
            "VersionLabel": version_label,
            "TemplateName": template_name,
            "SolutionStackName": solution_stack_name,
            "PlatformArn": platform_arn,
            "OptionSettings": option_settings,
            "OptionsToRemove": options_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def subscribe(
    hub, ctx, consumer_arn: str, shard_id: str, starting_position: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    This operation establishes an HTTP/2 connection between the consumer you specify in the ConsumerARN parameter and the shard you specify in the ShardId parameter. After the connection is successfully established, Kinesis Data Streams pushes records from the shard to the consumer over this connection. Before you call this operation, call RegisterStreamConsumer to register the consumer with Kinesis Data Streams. When the SubscribeToShard call succeeds, your consumer starts receiving events of type SubscribeToShardEvent over the HTTP/2 connection for up to 5 minutes, after which time you need to call SubscribeToShard again to renew the subscription if you want to continue to receive records. You can make one call to SubscribeToShard per second per registered consumer per shard. For example, if you have a 4000 shard stream and two registered stream consumers, you can make one SubscribeToShard request per second for each combination of shard and registered consumer, allowing you to subscribe both consumers to all 4000 shards in one second.  If you call SubscribeToShard again with the same ConsumerARN and ShardId within 5 seconds of a successful call, you'll get a ResourceInUseException. If you call SubscribeToShard 5 seconds or more after a successful call, the first connection will expire and the second call will take over the subscription. For an example of how to use this operations, see Enhanced Fan-Out Using the Kinesis Data Streams API.

    Args:
        consumer_arn(str): For this parameter, use the value you obtained when you called RegisterStreamConsumer.
        shard_id(str): The ID of the shard you want to subscribe to. To see a list of all the shards for a given stream, use ListShards.
        starting_position(Dict): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.to_shard.subscribe(
                ctx, consumer_arn=value, shard_id=value, starting_position=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.to_shard.subscribe consumer_arn=value, shard_id=value, starting_position=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="subscribe_to_shard",
        op_kwargs={
            "ConsumerARN": consumer_arn,
            "ShardId": shard_id,
            "StartingPosition": starting_position,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, endpoint_arn: str, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the schema for the specified endpoint.

    Args:
        endpoint_arn(str): The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.schemas.describe(ctx, endpoint_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.schemas.describe endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_schemas",
        op_kwargs={
            "EndpointArn": endpoint_arn,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def refresh(hub, ctx, endpoint_arn: str, replication_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Populates the schema for the specified endpoint. This is an asynchronous operation and can take several minutes. You can check the status of this operation by calling the DescribeRefreshSchemasStatus operation.

    Args:
        endpoint_arn(str): The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.schemas.refresh(
                ctx, endpoint_arn=value, replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.schemas.refresh endpoint_arn=value, replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="refresh_schemas",
        op_kwargs={
            "EndpointArn": endpoint_arn,
            "ReplicationInstanceArn": replication_instance_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def associate(hub, ctx, environment_name: str, operations_role: str) -> None:
    r"""
    **Autogenerated function**

    Add or change the operations role used by an environment. After this call is made, Elastic Beanstalk uses the associated operations role for permissions to downstream services during subsequent calls acting on this environment. For more information, see Operations roles in the AWS Elastic Beanstalk Developer Guide.

    Args:
        environment_name(str): The name of the environment to which to set the operations role.
        operations_role(str): The Amazon Resource Name (ARN) of an existing IAM role to be used as the environment's operations role.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.operation_role.associate(
                ctx, environment_name=value, operations_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.operation_role.associate environment_name=value, operations_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="associate_environment_operations_role",
        op_kwargs={
            "EnvironmentName": environment_name,
            "OperationsRole": operations_role,
        },
    )


async def disassociate(hub, ctx, environment_name: str) -> None:
    r"""
    **Autogenerated function**

    Disassociate the operations role from an environment. After this call is made, Elastic Beanstalk uses the caller's permissions for permissions to downstream services during subsequent calls acting on this environment. For more information, see Operations roles in the AWS Elastic Beanstalk Developer Guide.

    Args:
        environment_name(str): The name of the environment from which to disassociate the operations role.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.operation_role.disassociate(
                ctx, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.operation_role.disassociate environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="disassociate_environment_operations_role",
        op_kwargs={"EnvironmentName": environment_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, group_name: str = None, group: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource query associated with the specified resource group. For more information about resource queries, see Create a tag-based group in Resource Groups.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:GetGroupQuery

    Args:
        group_name(str, optional): Don't use this parameter. Use Group instead. Defaults to None.
        group(str, optional): The name or the ARN of the resource group to query. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.query.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.query.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="get_group_query",
        op_kwargs={"GroupName": group_name, "Group": group},
    )


async def update(
    hub, ctx, resource_query: Dict, group_name: str = None, group: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:UpdateGroupQuery

    Args:
        group_name(str, optional): Don't use this parameter. Use Group instead. Defaults to None.
        group(str, optional): The name or the ARN of the resource group to query. Defaults to None.
        resource_query(Dict): The resource query to determine which AWS resources are members of this resource group.  A resource group can contain either a Configuration or a ResourceQuery, but not both. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.query.update(ctx, resource_query=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.query.update resource_query=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="update_group_query",
        op_kwargs={
            "GroupName": group_name,
            "Group": group,
            "ResourceQuery": resource_query,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, policy_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of PolicyComplianceStatus objects. Use PolicyComplianceStatus to get a summary of which member accounts are protected by the specified policy.

    Args:
        policy_id(str): The ID of the Firewall Manager policy that you want the details for.
        next_token(str, optional): If you specify a value for MaxResults and you have more PolicyComplianceStatus objects than the number that you specify for MaxResults, Firewall Manager returns a NextToken value in the response that allows you to list another group of PolicyComplianceStatus objects. For the second and subsequent ListComplianceStatus requests, specify the value of NextToken from the previous response to get information about another batch of PolicyComplianceStatus objects. Defaults to None.
        max_results(int, optional): Specifies the number of PolicyComplianceStatus objects that you want Firewall Manager to return for this request. If you have more PolicyComplianceStatus objects than the number that you specify for MaxResults, the response includes a NextToken value that you can use to get another batch of PolicyComplianceStatus objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.compliance.status.list(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.compliance.status.list policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="list_compliance_status",
        op_kwargs={
            "PolicyId": policy_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cluster_subnet_group_name: str,
    description: str,
    subnet_ids: List,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon Redshift subnet group. You must provide a list of one or more subnets in your existing Amazon Virtual Private Cloud (Amazon VPC) when creating Amazon Redshift subnet group.  For information about subnet groups, go to Amazon Redshift Cluster Subnet Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_subnet_group_name(str): The name for the subnet group. Amazon Redshift stores the value as a lowercase string. Constraints:   Must contain no more than 255 alphanumeric characters or hyphens.   Must not be "Default".   Must be unique for all subnet groups that are created by your Amazon Web Services account.   Example: examplesubnetgroup .
        description(str): A description for the subnet group.
        subnet_ids(List): An array of VPC subnet IDs. A maximum of 20 subnets can be modified in a single request.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.subnet_group.create(
                ctx, cluster_subnet_group_name=value, description=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.subnet_group.create cluster_subnet_group_name=value, description=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_cluster_subnet_group",
        op_kwargs={
            "ClusterSubnetGroupName": cluster_subnet_group_name,
            "Description": description,
            "SubnetIds": subnet_ids,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, cluster_subnet_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified cluster subnet group.

    Args:
        cluster_subnet_group_name(str): The name of the cluster subnet group name to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.subnet_group.delete(
                ctx, cluster_subnet_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.subnet_group.delete cluster_subnet_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_cluster_subnet_group",
        op_kwargs={"ClusterSubnetGroupName": cluster_subnet_group_name},
    )


async def describe_all(
    hub,
    ctx,
    cluster_subnet_group_name: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns one or more cluster subnet group objects, which contain metadata about your cluster subnet groups. By default, this operation returns information about all cluster subnet groups that are defined in your Amazon Web Services account. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all subnet groups that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all subnet groups that have any combination of those values are returned. If both tag keys and values are omitted from the request, subnet groups are returned regardless of whether they have tag keys or values associated with them.

    Args:
        cluster_subnet_group_name(str, optional): The name of the cluster subnet group for which information is requested. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterSubnetGroups request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching cluster subnet groups that are associated with the specified key or keys. For example, suppose that you have subnet groups that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the subnet groups that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching cluster subnet groups that are associated with the specified tag value or values. For example, suppose that you have subnet groups that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the subnet groups that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.subnet_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.subnet_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_subnet_groups",
        op_kwargs={
            "ClusterSubnetGroupName": cluster_subnet_group_name,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )


async def modify(
    hub, ctx, cluster_subnet_group_name: str, subnet_ids: List, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a cluster subnet group to include the specified list of VPC subnets. The operation replaces the existing list of subnets with the new list of subnets.

    Args:
        cluster_subnet_group_name(str): The name of the subnet group to be modified.
        description(str, optional): A text description of the subnet group to be modified. Defaults to None.
        subnet_ids(List): An array of VPC subnet IDs. A maximum of 20 subnets can be modified in a single request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.subnet_group.modify(
                ctx, cluster_subnet_group_name=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.subnet_group.modify cluster_subnet_group_name=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster_subnet_group",
        op_kwargs={
            "ClusterSubnetGroupName": cluster_subnet_group_name,
            "Description": description,
            "SubnetIds": subnet_ids,
        },
    )
